@@ -59,6 +59,7 @@ from kalavai_client.core import (
     add_node_labels,
     get_node_labels,
     generate_worker_package,
+    get_deployment_values,
     TokenType
 )
 from kalavai_client.utils import (
@@ -102,10 +103,8 @@ def pool_create(request: CreatePoolRequest, api_key: str = Depends(verify_api_ke
     
     - **cluster_name**: Name of the cluster
     - **ip_address**: IP address for the pool
-    - **app_values**: Application configuration values
     - **num_gpus**: Number of GPUs to allocate
     - **node_name**: Name of the node
-    - **only_registered_users**: Whether to restrict to registered users
     - **location**: Location of the pool
     - **description**: Pool description
     - **token_mode**: Token type for authentication
@@ -113,7 +112,6 @@ def pool_create(request: CreatePoolRequest, api_key: str = Depends(verify_api_ke
     result = create_pool(
         cluster_name=request.cluster_name,
         ip_address=request.ip_address,
-        app_values=request.app_values,
         num_gpus=request.num_gpus,
         node_name=request.node_name,
         location=request.location,
@@ -449,6 +447,20 @@ def job_deploy(request: DeployJobRequest, api_key: str = Depends(verify_api_key)
     )
     return result
 
+@app.get("/get_deployment_values",
+    operation_id="get_deployment_values",
+    summary="Get deployment template values for a given model",
+    description="Given a model id from Huggingface, return the deployment template values required to load the model instance in the pool, including number of workers, number of gpus and gpu backend.",
+    tags=["job_management"],
+    response_description="Deployment template values")
+def get_deployment_template_values(model_id: str, api_key: str = Depends(verify_api_key)):
+    """
+    Get the deployment template values for a given model id:
+    
+    - **model_id**: Model id from Huggingface type mode
+    """
+    return get_deployment_values(model_id=model_id)
+
 @app.post("/delete_job",
     operation_id="delete_job",
     summary="Terminate and remove a job from the pool",
