@@ -62,7 +62,8 @@ from kalavai_client.core import (
     uncordon_nodes,
     TokenType,
     unregister_pool,
-    update_pool
+    update_pool,
+    get_deployment_values
 )
 from kalavai_client.utils import (
     check_gpu_drivers,
@@ -396,7 +397,8 @@ def pool__list(*others, user_only=False):
 
 
 @arguably.command
-def pool__start(cluster_name, *others,  platform="amd64", ip_address: str=None, location: str=None, app_values: str=None, pool_config_values: str=None, non_interactive: bool=False):
+def pool__start(*others,  pool_config_file=None, apps: list=None, mtu: str=None, platform="amd64", ip_address: str=None, location: str=None, app_values: str=None, pool_config_values: str=None, non_interactive: bool=False):
+
     """
     Start Kalavai pool and start/resume sharing resources.
 
@@ -430,16 +432,16 @@ def pool__start(cluster_name, *others,  platform="amd64", ip_address: str=None,
     
     console.log(f"Using {ip_address} address for server")
 
-    console.log(f"[green]Creating {cluster_name} pool, this may take a few minutes...")
+    console.log(f"[green]Creating pool, this may take a few minutes...")
 
     result = create_pool(
-        target_platform=platform,
-        cluster_name=cluster_name,
         ip_address=ip_address,
-        app_values=app_values,
-        pool_config_values=pool_config_values,
+        location=location,
+        target_platform=platform,
+        pool_config_file=pool_config_file,
+        apps=apps,
         num_gpus=input_gpus(non_interactive=non_interactive),
-        location=location
+        mtu=mtu
     )
 
     if "warning" in result:
@@ -482,7 +484,7 @@ def pool__token(*others, admin=False, user=False, worker=False):
     return join_token
 
 @arguably.command
-def pool__check_token(token, *others, public=False):
+def pool__check_token(token, *others, public=False, verbose=False):
     """
     Utility to check the validity of a join token
     """
@@ -490,12 +492,14 @@ def pool__check_token(token, *others, public=False):
     if "error" in result:
         console.log(f"[red]Error in token: {result}")
         return False
+    if verbose:
+        console.log(json.dumps(result["data"], indent=2))
     
     console.log("[green]Token format is correct")
     return True
 
 @arguably.command
-def pool__join(token, *others, platform="amd64", node_name=None, non_interactive=False):
+def pool__join(token, *others, mtu=None, platform="amd64", node_name=None, non_interactive=False):
     """
     Join Kalavai pool and start/resume sharing resources.
 
@@ -549,7 +553,8 @@ def pool__join(token, *others, platform="amd64", node_name=None, non_interactive
         token=token,
         node_name=node_name,
         num_gpus=num_gpus,
-        ip_address=ip_address
+        ip_address=ip_address,
+        mtu=mtu
     )
     if "error" in result:
         console.log(f"[red]Error when connecting: {result}")
@@ -1165,6 +1170,12 @@ def job__delete(name, *others, force_namespace: str=None):
         console.log(f"{result}")
 
 
+@arguably.command
+def job__model_requirements(model_id: str, *others):
+    values = get_deployment_values(model_id=model_id)
+    console.log(values)
+
+
 @arguably.command
 def job__estimate(
     *others, 
@@ -1180,6 +1191,7 @@ def job__estimate(
     precision_bytes = {
         "fp32": 4,
         "fp16": 2,
+        "fp8": 1,
         "int8": 1,
         "int4": 0.5
     }
