@@ -1,7 +1,8 @@
 import os
+import yaml
 import time
 from collections import defaultdict
-import math
+import random
 import uuid
 import socket
 import ipaddress
@@ -68,10 +69,10 @@ from kalavai_client.env import (
     USER_NODE_LABEL,
     DEFAULT_WATCHER_PORT,
     HELM_APPS_FILE,
-    HELM_APPS_VALUES,
-    POOL_CONFIG_DEFAULT_VALUES,
+    MODEL_DEPLOYMENT_VALUES_MAPPING,
     POOL_CONFIG_TEMPLATE,
-    FORBIDEDEN_IPS
+    FORBIDEDEN_IPS,
+    DEFAULT_POOL_CONFIG_TEMPLATE
 )
 
 class Job(BaseModel):
@@ -103,6 +104,70 @@ class TokenType(Enum):
     WORKER = 2
 
 
+def get_deployment_values(model_id: str):
+    """
+    Given a model ID and the resources in the pool, identify key
+    computing values required to deploy the model.
+    - GPU_BACKEND: rocm or cuda
+    - WORKERS: number of nodes to use
+    - 
+    """
+    # get hardcoded deployment values (per model)
+    with open(MODEL_DEPLOYMENT_VALUES_MAPPING, "r") as f:
+        mapping = yaml.safe_load(f)
+
+    def _parse_memory_str(memory: str):
+        memory = memory.replace("G", "")
+        return int(memory)
+    
+    def _get_num_workers(memory_values: list[int], size):
+        workers = 0
+        available_memory = 0
+        for gpu_mem in memory_values:
+            available_memory += gpu_mem
+            workers += 1
+            if available_memory >= size:
+                break
+        return workers
+    
+    # get resources
+    if model_id in mapping:
+        model_size = mapping[model_id]["size"]
+        # get gpus and extract available memory
+        nvidia_gpu_mems = []
+        amd_gpu_mems = []
+        backends = set()
+        for node_name, gpus in load_gpu_models():
+            for gpu in gpus["gpus"]:
+                if "nvidia" in gpu["model"].lower():
+                    nvidia_gpu_mems.append(_parse_memory_str(gpu["memory"]))
+                    backends.add("cuda")
+                else:
+                    amd_gpu_mems.append(_parse_memory_str(gpu["memory"]))
+                    backends.add("rocm")
+        nvidia_gpu_mems = sorted(nvidia_gpu_mems, reverse=False)
+        amd_gpu_mems = sorted(amd_gpu_mems, reverse=False)
+        # calculate num workers required
+        if sum(nvidia_gpu_mems) >= model_size and sum(amd_gpu_mems) < model_size:
+            gpu_backend = "cuda"
+            num_workers = _get_num_workers(memory_values=nvidia_gpu_mems, size=model_size)
+        elif sum(amd_gpu_mems) >= model_size and sum(nvidia_gpu_mems) < model_size:
+            gpu_backend = "rocm"
+            num_workers = _get_num_workers(memory_values=amd_gpu_mems, size=model_size)
+        else:
+            gpu_backend = random.choice(list(backends))
+            num_workers = _get_num_workers(
+                memory_values=amd_gpu_mems if gpu_backend == "rocm" else nvidia_gpu_mems,
+                size=model_size
+            )
+        # populate selected template
+        mapping[model_id][gpu_backend]["values"]["workers"] = num_workers
+        mapping[model_id][gpu_backend]["values"]["pipeline_parallel_size"] = num_workers
+
+        return mapping[model_id][gpu_backend]
+    return None
+
+
 def set_schedulable(schedulable, node_names):
     """
     Delete job in the cluster
@@ -505,7 +570,7 @@ def fetch_gpus(available=False):
                 status = gpu["ready"] if "ready" in gpu else True
                 if available and not status:
                     continue
-                row_gpus.append( (f"{gpu['model']} ({math.floor(int(gpu['memory'])/1000)} GBs)", str(status)))
+                row_gpus.append( (f"{gpu['model']} ({gpu['memory']} vRAM)", str(status)))
             if len(row_gpus) > 0:
                 models, statuses = zip(*row_gpus)
                 #rows.append([node, "\n".join(statuses), "\n".join(models), str(gpus["available"]), str(gpus["capacity"])])
@@ -543,7 +608,7 @@ def check_token(token, public=False):
         if public:
             if data[PUBLIC_LOCATION_KEY] is None:
                 raise ValueError("Token is not valid for public pools. Did you start the cluster with a public_location?")
-        return {"status": True}
+        return {"status": True, "data": data}
     except Exception as e:
         return {"error": str(e)}
     
@@ -669,7 +734,8 @@ def join_pool(
         num_gpus=None,
         node_name=None,
         ip_address=None,
-        target_platform="amd64"
+        target_platform="amd64",
+        mtu="1420"
 ):
     compatibility = check_worker_compatibility()
     if len(compatibility["issues"]) > 0:
@@ -712,6 +778,7 @@ def join_pool(
         pool_token=kalavai_token,
         num_gpus=num_gpus,
         vpn_token=public_location,
+        mtu=mtu,
         node_name=node_name,
         node_labels=node_labels)
     
@@ -752,48 +819,61 @@ def join_pool(
     return cluster_name
 
 def create_pool(
-        cluster_name: str,
-        ip_address: str,
+        cluster_name: str=None,
+        ip_address: str=None,
+        location: str=None,
+        target_platform: str="amd64",
+        pool_config_file: str=None,
         description: str="",
         token_mode: TokenType=TokenType.USER,
-        app_values: str=None,
-        pool_config_values: str=None,
-        num_gpus: int=0,
+        num_gpus: int=-1,
         node_name: str=None,
-        location: str=None,
-        target_platform: str="amd64"
+        mtu: str=None,
+        apps: list=[]
     ):
 
     if not check_seed_compatibility():
         return {"error": "Requirements failed"}
     
-    if app_values is None:
-        app_values = HELM_APPS_VALUES
-    
-    if pool_config_values is None:
-        pool_config_values = POOL_CONFIG_DEFAULT_VALUES
+    if pool_config_file is None:
+        pool_config_file = DEFAULT_POOL_CONFIG_TEMPLATE
+
+    if node_name is None:
+        node_name = socket.gethostname()
 
-    node_name = socket.gethostname()
     user_id = load_user_id()
     
     node_labels = {
         STORAGE_CLASS_LABEL: is_storage_compatible(),
         NODE_ROLE_LABEL: "server"
     }
-
-    # if location is not None:
-    #     try:
-    #         vpn = get_vpn_details(
-    #             location=location,
-    #             user_cookie=USER_COOKIE)
-    #         node_labels[USER_NODE_LABEL] = user["username"]
-    #     except Exception as e:
-    #         return {"error": f"[red]Error when joining network: {str(e)}"}
         
-    if num_gpus is None:
+    if num_gpus < 0:
         num_gpus = get_max_gpus()
-    
+
+    # load values from pool config
+    with open(pool_config_file, "r") as f:
+        config_values = yaml.safe_load(f)
+    # use default values if not provided
+    try:
+        cluster_name = config_values["server"]["name"] if cluster_name is None else cluster_name
+        ip_address = config_values["server"]["ip_address"] if ip_address is None else ip_address
+        location = config_values["server"]["location"] if location is None else location
+        target_platform = config_values["server"]["platform"] if target_platform is None else target_platform
+        mtu = config_values["server"]["mtu"] if mtu is None else mtu
+        app_values = config_values["core"]
+        post_config_values = config_values["pool"]
+        deploy_apps = {
+            f"deploy_{app}": True for app in config_values["core"]["deploy"]
+        }
+        for app in apps:
+            deploy_apps[f"deploy_{app}"] = True
+    except Exception as e:
+        return {"error": f"Error when loading pool config. Missing format? {str(e)}"}
+
     # Generate docker compose recipe
+    if ip_address is None:
+        ip_address = "0.0.0.0"
     generate_compose_config(
         target_platform=target_platform,
         role="server",
@@ -801,7 +881,8 @@ def create_pool(
         node_ip_address=ip_address,
         num_gpus=num_gpus,
         node_name=node_name,
-        node_labels=node_labels
+        node_labels=node_labels,
+        mtu=mtu
     )
 
     # start server
@@ -818,13 +899,12 @@ def create_pool(
             time.sleep(10)
 
     # populate local cred files
-    
     auth_key = user_id if user_id is not None else str(uuid.uuid4())
     write_auth_key = str(uuid.uuid4())
     readonly_auth_key = str(uuid.uuid4())
     watcher_service = f"{ip_address}:{DEFAULT_WATCHER_PORT}"
     values = {
-        CLUSTER_NAME_KEY: cluster_name,
+        #CLUSTER_NAME_KEY: cluster_name,
         CLUSTER_IP_KEY: ip_address,
         USER_ID_KEY: user_id if user_id is not None else "",
         AUTH_KEY: auth_key,
@@ -851,8 +931,8 @@ def create_pool(
     # Generate helmfile recipe
     helm_yaml = load_template(
         template_path=HELM_APPS_FILE,
-        values=values,
-        default_values_path=app_values,
+        values={**values, **deploy_apps, **app_values},
+        #default_values_path=app_values,
         force_defaults=True)
     with open(USER_HELM_APPS_FILE, "w") as f:
         f.write(helm_yaml)
@@ -864,11 +944,6 @@ def create_pool(
         )
     except Exception as e:
         return {"error": f"Error when updating dependencies: {str(e)}"}
-
-    if location is not None:
-        # TODO: register with kalavai if it's a public cluster
-        pass
-        #pool__publish()
     
     # wait until the server is ready to create objects
     while True:
@@ -876,7 +951,7 @@ def create_pool(
         if is_watcher_alive(server_creds=USER_LOCAL_SERVER_FILE, user_cookie=USER_COOKIE):
             break
 
-    result = pool_init(pool_config_values_path=pool_config_values)
+    result = pool_init(config_values=post_config_values)
     if "error" in result or ("failed" in result and len(result['failed']) > 0):
         return {"error": f"Error when initialising pool: {result}"}
     # init default namespace
@@ -953,16 +1028,15 @@ def get_pool_token(mode: TokenType):
     except Exception as e:
         return {"error": f"Error when generating token: {str(e)}"}
 
-def pool_init(pool_config_values_path=None):
+def pool_init(config_values=None):
     """Deploy configured objects to initialise pool"""
-    if pool_config_values_path is None:
+    if config_values is None:
         return
     
     # load template config and populate with values
     sidecar_template_yaml = load_template(
         template_path=POOL_CONFIG_TEMPLATE,
-        values={},
-        default_values_path=pool_config_values_path)
+        values=config_values)
 
     try:
         result = request_to_server(
